@@ -87,8 +87,11 @@ sub install {
 	my $this=shift;
 	my $deb=shift;
 
+	my $v=$Alien::Package::verbose;
+	$Alien::Package::verbose=2;
 	$this->do("dpkg", "--no-force-overwrite", "-i", $deb)
 		or die "Unable to install";
+	$Alien::Package::verbose=$v;
 }
 
 =item test
@@ -646,10 +649,10 @@ Returns the date, in rfc822 format.
 sub date {
 	my $this=shift;
 
-	my $date=$this->runpipe(1, "822-date");
+	my $date=$this->runpipe(1, "date -R");
 	chomp $date;
 	if (!$date) {
-		die "822-date did not return a valid result. You probably need to install the dpkg-dev debian package";
+		die "date -R did not return a valid result.";
 	}
 
 	return $date;
